California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance Activity Propositions & Ballot Measures
Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
All of the campaign committees that have organized to support or oppose propositions and ballot measures on California's statewide ballot are available here. Click below on the proposition or ballot measure to learn who is involved in the campaign to win your vote on Election Day.
Prior Elections
NOVEMBER 3, 2020, GENERAL
12 Measures
PROPOSITION 014 - AUTHORIZES BONDS TO CONTINUE FUNDING STEM CELL AND OTHER MEDICAL RESEARCH. INITIATIVE STATUTE.
PROPOSITION 015 - INCREASES FUNDING FOR PUBLIC SCHOOLS, COMMUNITY COLLEGES, AND LOCAL GOVERNMENT SERVICES BY CHANGING TAX ASSESSMENT OF COMMERCIAL AND INDUSTRIAL PROPERTY. INITIATIVE CONSTITUTIONAL...
PROPOSITION 016 - ACA 5 (RESOLUTION CHAPTER 23), WEBER. GOVERNMENT PREFERENCES.
PROPOSITION 017 - ACA 6 (RESOLUTION CHAPTER 24), MCCARTY. ELECTIONS: DISQUALIFICATION OF ELECTORS.
PROPOSITION 018 - ACA 4 (RESOLUTION CHAPTER 30), MULLIN. ELECTIONS: VOTING AGE.
PROPOSITION 019 - ACA 11 (RESOLUTION CHAPTER 31), MULLIN. THE HOME PROTECTION FOR SENIORS, SEVERELY DISABLED, FAMILIES, AND VICTIMS OF WILDFIRE OR NATURAL DISASTERS ACT.
PROPOSITION 020 - RESTRICTS PAROLE FOR NON-VIOLENT OFFENDERS. AUTHORIZES FELONY SENTENCES FOR CERTAIN OFFENSES CURRENTLY TREATED ONLY AS MISDEMEANORS. INITIATIVE STATUTE.
PROPOSITION 021 - EXPANDS LOCAL GOVERNMENTS' AUTHORITY TO ENACT RENT CONTROL ON RESIDENTIAL PROPERTY. INITIATIVE STATUTE.
PROPOSITION 022 - CHANGES EMPLOYMENT CLASSIFICATION RULES FOR APP-BASED TRANSPORTATION AND DELIVERY DRIVERS. INITIATIVE STATUTE.
PROPOSITION 023 - AUTHORIZES STATE REGULATION OF KIDNEY DIALYSIS CLINICS. ESTABLISHES MINIMUM STAFFING AND OTHER REQUIREMENTS. INITIATIVE STATUTE.
PROPOSITION 024 - AMENDS CONSUMER PRIVACY LAWS. INITIATIVE STATUTE.
PROPOSITION 025 - REFERENDUM TO OVERTURN A 2018 LAW THAT REPLACED MONEY BAIL SYSTEM WITH A SYSTEM BASED ON PUBLIC SAFETY RISK.
MARCH 3, 2020, PRIMARY
1 Measure
PROPOSITION 013 - AB 48 (CHAPTER 530, STATUTES OF 2019), O'DONNELL. EDUCATION FINANCE: SCHOOL FACILITIES: PUBLIC PRESCHOOL, K-12, AND COLLEGE HEALTH AND SAFETY BOND ACT OF 2020